<?php
namespace webaware\gf_dpspxpay;

if (!defined('ABSPATH')) {
	exit;
}

/**
* Windcave payment result response
*/
class GFDpsPxPayResponseResult extends GFDpsPxPayResponse {

	/**
	* For a successful transaction "True" is passed and for a failed transaction "False" is passed.
	* @var boolean
	*/
	public $Success;

	/**
	* requested amount of payment as settled, in dollars and cents as a floating-point number, excluding surcharges
	* @var float
	*/
	public $AmountSettlement;

	/**
	* total amount of payment as processed, in dollars and cents as a floating-point number, including surcharges
	* if there is no surcharge, this field will be omitted
	* @var float
	*/
	public $TotalAmount;

	/**
	* surcharge amount added to requested payment amount, in dollars and cents as a floating-point number
	* if there is no surcharge, this field will be omitted
	* @var float
	*/
	public $AmountSurcharge;

	/**
	* If the transaction is successful, this is the bank authorisation number.
	* @var string max. 22 characters
	*/
	public $AuthCode;

	/**
	* name on credit card
	* @var string max. 64 characters
	*/
	public $CardHolderName;

	/**
	* name of credit card, e.g. Visa, Mastercard, Amex, Diners
	* @var string max. 16 characters
	*/
	public $CardName;

	/**
	* credit card number, with no spaces, obfuscated
	* @var string max. 16 characters
	*/
	public $CardNumber;

	/**
	* credit card number expiry date (MMYY)
	* @var string max. 4 characters
	*/
	public $DateExpiry;

	/**
	* DPS transaction reference
	* @var string max. 16 characters
	*/
	public $DpsTxnRef;

	/**
	* textual response status, e.g. APPROVED
	* @var string max. 32 characters
	*/
	public $ResponseText;

	/**
	* Windcave billing ID generated when creating a new token
	* @var string max. 16 characters
	*/
	public $DpsBillingId;

	/**
	* the currency of the settlement
	* @var string max. 4 characters
	*/
	public $CurrencySettlement;

	/**
	* the currency of the payment request
	* @var string max. 4 characters
	*/
	public $CurrencyInput;

	/**
	* optional additional information for use in shopping carts, etc.
	* @var string max. 255 characters
	*/
	public $TxnData1;

	/**
	* optional additional information for use in shopping carts, etc.
	* @var string max. 255 characters
	*/
	public $TxnData2;

	/**
	* optional additional information for use in shopping carts, etc.
	* @var string max. 255 characters
	*/
	public $TxnData3;

	/**
	* type of transaction (Purchase, Auth)
	* @var string max. 8 characters
	*/
	public $TxnType;

	/**
	* an invoice reference to track by
	* @var string max. 64 characters
	*/
	public $MerchantReference;

	/**
	* IP address of the client
	* @var string
	*/
	public $ClientInfo;

	/**
	* transaction number passed in payment request
	* @var string max. 16 characters
	*/
	public $TxnId;

	/**
	* customer's email address
	* @var string max. 255 characters
	*/
	public $EmailAddress;

	/**
	* indication of uniqueness of card number
	* @var string
	*/
	public $TxnMac;

	/**
	* a token generated by DPS when adding a card for recurring billing
	* @var string max. 16 characters
	*/
	public $CardNumber2;

	/**
	* CVC / CVV2 Result Code associated with the result of the CVC validation
	* @var string max. 1 character
	*/
	public $Cvc2ResultCode;

	/**
	* record whether transaction was user cancelled
	* @var bool
	*/
	public $WasUserCancelled = false;

	/**
	* get 'invalid response' message for this response class
	* @return string
	*/
	protected function getMessageInvalid() {
		return __('Invalid response from Windcave for payment response', 'gravity-forms-dps-pxpay');
	}

	/**
	* get an array of processing messages
	* @return array
	*/
	public function getProcessingMessages() {
		$msg = $this->ResponseText;
		if ($msg === 'DECLINED' && $this->CardHolderName === 'User Cancelled') {
			$msg = 'User Cancelled';
			$this->WasUserCancelled = true;
		}

		return [$msg];
	}

}
